# Async Iterable to Readable Stream

[![CircleCI](https://circleci.com/gh/bunchtogether/async-iterable-to-readable-stream.svg?style=svg)](https://circleci.com/gh/bunchtogether/async-iterable-to-readable-stream) [![npm version](https://badge.fury.io/js/async-iterable-to-readable-stream.svg)](http://badge.fury.io/js/async-iterable-to-readable-stream)

Convert an async iterable into a readable stream. No dependencies.

If you encounter an issue, fork the repository, [write tests demonstrating](https://github.com/bunchtogether/async-iterable-to-readable-stream/tree/master/tests) the issue, and create a [pull request](https://github.com/bunchtogether/async-iterable-to-readable-stream).

```js
const asyncIterableToReadableStream = require('async-iterable-to-readable-stream');
const crypto = require('crypto');

const chunks = [
  crypto.randomBytes(Math.round(Math.random() * 256)),
  crypto.randomBytes(Math.round(Math.random() * 256)),
  crypto.randomBytes(Math.round(Math.random() * 256)),
  crypto.randomBytes(Math.round(Math.random() * 256)),
];

async function* getChunks() {
  for (const item of chunks) {
    await new Promise((resolve) => setImmediate(resolve));
    yield item;
  }
}

const iterable = getChunks();

const stream = asyncIterableToReadableStream(iterable);

stream.on('data', (chunk) => {
  console.log(`Chunk with length ${chunk.length}`);
});

stream.on('error', (error) => {
  console.error(error);
});

stream.on('end', () => {
  console.log("End");
});

stream.on('close', () => {
  console.log("Close");
});
```

## Install

`yarn add async-iterable-to-readable-stream`

## API

<!-- Generated by documentation.js. Update this documentation by updating the source code. -->

#### Table of Contents

-   [index](#index)
    -   [Parameters](#parameters)

### index

Convert an async iterable into a readable stream

#### Parameters

-   `iterable` **AsyncIterable&lt;([Buffer](https://nodejs.org/api/buffer.html) \| [string](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String))>** 

Returns **any** Readable&lt;Buffer | string>
